@@ -36,7 +36,9 @@ def write_model(file_name, model):
 
 def read_model(file_name):
     config = _config()
-    return model_from_json(_get_object(config, config['bucket_name'], file_name)['Body'].read())
+    response = _get_object(config, config['bucket_name'], file_name)['Body'].read().decode('utf-8')
+    print(json.loads(response))
+    return model_from_json(response)
 
 
 
